<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Kullanıcı Yöneticisi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Yönetim</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Yeni bir kullanıcı ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Kullanıcı Hesabı Ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Yeni kullanıcı için parolayı tekrar girin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>parolayı onayla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Username of new user</source>
        <translation>Yeni kullanıcının kullanıcı adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>User login name:</source>
        <translation>Kullanıcı giriş adı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Enter username of new user</source>
        <translation>Yeni kullanıcının kullanıcı adını girin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>username</source>
        <translation>kullanıcı adı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Password for new user</source>
        <translation>Yeni kullanıcı için parola </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User password:</source>
        <translation>Kullanıcı parolası:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Enter password for new user</source>
        <translation>Yeni kullanıcı için parola girişi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>password</source>
        <translation>parola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Confirm user password:</source>
        <translation>Kullanıcı parolasını onayla:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Delete User Account</source>
        <translation>Kullanıcı Hesabı Silme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Select user</source>
        <translation>Kullanıcı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <location filename="../mainwindow.ui" line="1426"/>
        <source>Select user to delete</source>
        <translation>Silinecek kullanıcı seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>User to delete:</source>
        <translation>Silinecek kullanıcı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Ayrıca kullanıcının ev dizinini sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Delete user home directory</source>
        <translation>Kullanıcı ev dizinini sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>Rename User Account</source>
        <translation>Kullanıcı Hesabını Yeniden Adlandır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Select user to modify:</source>
        <translation>Değiştirilecek kullanıcıyı seç:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>New user name:</source>
        <translation>Yeni kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Change User Password</source>
        <translation>Kullananıcı parolasını değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>new password</source>
        <translation>yeni parola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Confirm new password:</source>
        <translation>Yeni parolayı onayla:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>confirm new password</source>
        <translation>Yeni parolayı onayla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>New user password:</source>
        <translation>Yeni kullanıcı parolası:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Repair a user configuration</source>
        <translation>kullanıcı yapılandırmasını onar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Modify User Account</source>
        <translation>Kullanıcı Hesabını Değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Select user to repair</source>
        <translation>Onarılacak kullanıcıyı seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="1435"/>
        <source>User to change:</source>
        <translation>Değişecek kullanıcı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Restore Defaults</source>
        <translation>Öntanımlılara Geri Dön</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="728"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>MX öntanımlı tarayıcı yapılandırmasını geri yükle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Firefox veya İceweasel) yapılandırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>MX öntanımlı grup üyeliklerini geri yükle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Group memberships</source>
        <translation>Grup üyeleri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Change Autologin Settings</source>
        <translation>Otomatik Giriş Ayarlarını Değiştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Log in automatically</source>
        <translation>Otomatik olarak giriş</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>Require password to log in</source>
        <translation>Giriş için parola gerekli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>Copy/Sync</source>
        <translation>Kopyala/Eşzamanla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="818"/>
        <source>Copy Between Desktops</source>
        <translation>Masaüstleri Arasında Kopyalama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <location filename="../mainwindow.ui" line="912"/>
        <source>Select desktop to copy from</source>
        <translation>Kopyalanacak masaüstünü seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Select to only copy files</source>
        <translation>Sadece kopyalanacak dosyaları seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="861"/>
        <source>Copy only</source>
        <translation>Sadece kopyala</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <location filename="../mainwindow.ui" line="890"/>
        <source>Select desktop to copy to</source>
        <translation>Kopyalanacak masaüstünü seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <source>Copy to:</source>
        <translation>Şuraya kopyala:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="921"/>
        <source>Copy from:</source>
        <translation>Şuradan kopyala:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="934"/>
        <source>Select to copy and then delete differences</source>
        <translation>Kopyayı seç ve farklı olanları sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="937"/>
        <source>Sync</source>
        <translation>Eşzamanlama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="983"/>
        <source>Select to copy/sync Shared</source>
        <translation>Paylaşılanı kopyalamak/eşzamanlamak için seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="986"/>
        <source>Shared folder</source>
        <translation>Paylaşılan klasörler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="999"/>
        <source>Select to copy/sync entire home</source>
        <translation>Tüm ev dizinini kopyalama/eşzamanlama için seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Entire home</source>
        <translation>Tüm home klasörü</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Tarayıcı yapılandırmasını kopyalamak/eşzamanlamak  için seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox veya İceweasel) yapılandırma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1034"/>
        <source>Select to copy/sync Documents</source>
        <translation>Belgeleri kopyalamak/eşzamanlamak için seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1037"/>
        <source>Documents folder</source>
        <translation>Belgeler klasörü</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>What to copy/sync:</source>
        <translation>Kopyalanacak/eşzamanlanacak olan ne:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Progress</source>
        <translation>Süreç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1090"/>
        <location filename="../mainwindow.ui" line="1106"/>
        <source>Status of the changes</source>
        <translation>Değişikliklerin durumu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1109"/>
        <source>Status:</source>
        <translation>Durum:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1125"/>
        <source>Progress of the changes</source>
        <translation>Değişikliklerin durumu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1162"/>
        <source>Add/Remove Groups</source>
        <translation>Gruplar Ekle/Kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1174"/>
        <source>Add Group</source>
        <translation>Grup Ekle</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1252"/>
        <source>Group name:</source>
        <translation>Grup adı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1201"/>
        <source>Enter name of new group</source>
        <translation>Yeni grubun adını girin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1207"/>
        <source>groupname</source>
        <translation>grup adı </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Delete Group</source>
        <translation>Grup Sil</translation>
    </message>
    <message>
        <source>Select group to delete</source>
        <translation type="vanished">Silinecek grubu seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Silinecek grubu seç&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Group to delete:</source>
        <translation type="vanished">Silinecek grup:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1371"/>
        <source>Group Membership</source>
        <translation>Grup Üyeleri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1497"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Değiştirilecek kullanıcıyı seç&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Kullanıcının dahil olduğu gruplar (uygun kutuları seçerek / seçimi kaldırarak grupları değiştirin):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1468"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Başvurmadan önce lütfen seçimlerinizi tekrar kontrol ediniz, yanlış grup üyelikleri atamak sisteminizi bozabilir. Bir hata yaptıysanız, varsayılanları geri yüklemek için Seçenekler sekmesindeki grup üyeliğini geri yükle seçeneğini kullanın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1641"/>
        <source>Apply any changes</source>
        <translation>Değişiklikleri uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1573"/>
        <source>Cancel any changes then quit</source>
        <translation>Değişiklikleri iptal et ve çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1220"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1349"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1356"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1576"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1624"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1627"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="154"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="715"/>
        <location filename="../mainwindow.cpp" line="869"/>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="986"/>
        <source>none</source>
        <translation>hiçbiri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="875"/>
        <location filename="../mainwindow.cpp" line="883"/>
        <source>browse...</source>
        <translation>gözat...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Kullanıcı yapılandırması onarılacak.Lütfen şimdi bütün diğer  uygulamaları kapatın. Bittiğinde çıkış yapın veya yeniden başlatın.Şimdi onarmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>User group membership was restored.</source>
        <translation>Kullanıcı grup üyeliği geri yüklendi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Mozilla settings were reset.</source>
        <translation>Mozilla ayarları sıfırlandı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Autologin options</source>
        <translation>Otomatik giriş seçenekleri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>&apos;%1&apos; hesabı için otomatik giriş devre dışı bırakıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>&apos;%1&apos; hesabı için otomatik giriş etkinleştirildi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Kopyalanacak yeri belirtmelisiniz. Giriş yaptığınız için masaüstüne kopyalayamazsınız.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Kopyalamadan önce, diğer tüm uygulamaları kapatın. Kopyalanacak hedefin, kopyaladığınız dosyaları içerecek kadar büyük olduğundan emin olun. Masaüstleri arasında kopyalama yapmak, hedef masaüstündeki dosyalarınızı veya tercihlerinizi geçersiz kılabilir veya silebilir. İşleme devam etmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Synchronizing desktop...</source>
        <translation>Masaüstü eşitleniyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copying desktop...</source>
        <translation>Masaüstü kopyalanıyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Kullanıcı adı en az 2 karakter uzunluğunda olmalıdır. Devam etmeden önce lütfen daha uzun bir ad seçin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Kullanıcı adı özel karakterler veya boşluk içeremez.
Lütfen devam etmeden önce başka bir ad seçin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Üzgünüm bu ad kullanılıyor. Lütfen farklı bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Parola girdileri uyuşmuyor. Lütfen tekrar deneyin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Parola en az 2 karakter uzunluğunda olmalıdır.Devam etmeden önce daha uzun bir parola girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>The user was added ok.</source>
        <translation>Kullanıcı eklendi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>Kullanıcı ekleme başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Password successfully changed.</source>
        <translation>Parola başarıyla değiştirildi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Failed to change password.</source>
        <translation>Parola değiştirme başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Bu işlem geri alınamaz. % 1 kullanıcısını silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>The user has been deleted.</source>
        <translation>Kullanıcı silindi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to delete the user.</source>
        <translation>Kullanıcı silme başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Grup adı en az 2 karakter uzunluğunda olmalıdır.  Devam etmeden önce lütfen daha uzun bir ad seçin.&#xa0;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Grup adı küçük harf olmalı ve
özel karakterler ve boşluklar içermemelidir.
Devam etmeden önce lütfen başka bir ad seçin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Üzgünüm bu grup adı zaten var. Lütfen farklı bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>The system group was added ok.</source>
        <translation>Sistem grubu eklendi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Failed to add the system group.</source>
        <translation>Sistem grubu ekleme başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Bu işlem geri alınamaz. % 1 kullanıcısını silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The group has been deleted.</source>
        <translation>Grup silindi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Failed to delete the group.</source>
        <translation>Grup silme başarısız oldu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>The changes have been applied.</source>
        <translation>Dwğişiklikler uygulandı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Failed to apply group changes</source>
        <translation>Grup değişiklikleri uygulanamadı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>The selected user name is currently in use.</source>
        <translation>Seçilen kullanıcı adı şu an kullanılıyor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Bu kullanıcıyı yeniden adlandırmak için, lütfen oturumu kapatın ve başka bir kullanıcı hesabı kullanarak tekrar oturum açın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Kullanıcı adı küçük harf olmalı ve
özel karakterler ve boşluklar içermemelidir.
Devam etmeden önce lütfen başka bir ad seçin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Üzgünüm, bu ad sisteminizde zaten var. Lütfen farklı bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Kullanıcı yeniden adlandırılamadı. Lütfen kullanıcının giriş yapmadığından emin olun, yeniden başlatmanız gerekebilir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>The user was renamed.</source>
        <translation>Kullanıcı yeniden adlandırıldı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <location filename="../mainwindow.cpp" line="605"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Masaüstü eşitleniyor...tamam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Copying desktop...ok</source>
        <translation>Masaüstü kopyalanıyor...tamam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Masaüstü eşitleniyor...başarısız oldu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Copying desktop...failed</source>
        <translation>Masaüstü kopyalanıyor...başarısız oldu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Confirmation</source>
        <translation>Onay</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>İşlem gerçekleşmedi. Uygulamayı terketmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>About %1</source>
        <translation>Hakkında %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>MX Linux için basit kullanıcı yapılandırması</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>%1 License</source>
        <translation>%1 Telif Hakkı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Select folder to copy to</source>
        <translation>Kopyalanacak klasörü seçin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Görünüşe göre root olarak girmişsiniz, lütfen çıkın ve bu programı kullanmak için normal kullanıcı olarak girin. </translation>
    </message>
</context>
</TS>
